@@ -15,7 +15,7 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 
 # Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -357,7 +357,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<Config::Utils>.
+=over
+
+=item L<Config::Utils>
+
+Common config utilities.
+
+=back
 
 =head1 REPOSITORY
 
@@ -371,10 +377,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2011-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
